@@ -52,12 +52,13 @@ def publication_permissions(cls, groups=('managers', 'users')):
 
 def authority_permissions_etype(cls):
     """Set __permissions__ of `cls` entity type class to ensure user can
-    create/update/delete provided its authority is the same as the entity's
-    authority.
+    update/delete provided its authority is the same as the entity's authority.
+
+    Creation permission is ensured by permission of the authority relation.
     """
     cls.__permissions__ = {
         'read': ('managers', 'users', 'guests'),
-        'add': ('managers', ERQLExpression('U authority A, X authority A')),
+        'add': ('managers', 'users'),
         'update': ('managers', ERQLExpression('U authority A, X authority A')),
         'delete': ('managers', ERQLExpression('U authority A, X authority A')),
     }
