@@ -220,25 +220,10 @@ def is_hook_category_activated(self, category):
 
 
 # avoid disappearance of navtop components (https://www.cubicweb.org/17074195)
+# other part lies in views/patches.py
 
-from logilab.mtconverter import xml_escape  # noqa
-from cubicweb.uilib import js  # noqa
-from cubicweb.utils import UStringIO, json_dumps, js_href  # noqa
+from cubicweb.utils import json_dumps, js_href  # noqa
 from cubicweb.web import component  # noqa
-from cubicweb.web.views import ajaxcontroller, basetemplates, facets  # noqa
-
-
-@monkeypatch(facets.FilterBox)
-def _get_context(self):
-    view = self.cw_extra_kwargs.get('view')
-    context = getattr(view, 'filter_box_context_info', lambda: None)()
-    if context:
-        rset, vid, divid, paginate = context
-    else:
-        rset = self.cw_rset
-        vid, divid = None, 'contentmain'
-        paginate = view and view.paginable
-    return rset, vid, divid, paginate
 
 
 @monkeypatch(component.NavigationComponent)
@@ -249,66 +234,6 @@ def ajax_page_url(self, **params):
         json_dumps('#' + divid), component.js.ajaxFuncArgs('view', params)))
 
 
-@monkeypatch(basetemplates.TheMainTemplate)
-def content_column(self, view, content_cols):
-    w = self.w
-    w(u'<div id="main-center" class="%(prefix)s%(col)s" role="main">' % {
-        'prefix': self.twbs_col_cls, 'col': content_cols})
-    components = self._cw.vreg['components']
-    self.content_components(view, components)
-    w(u'<div id="pageContent">')
-    self.content_header(view)
-    vtitle = self._cw.form.get('vtitle')
-    if vtitle:
-        w(u'<div class="vtitle">%s</div>\n' % xml_escape(vtitle))
-    self.state_header()
-    self.content_navrestriction_components(view, components)
-    w(u'<div id="contentmain">\n')
-    nav_html = UStringIO()
-    if view and not view.handle_pagination:
-        view.paginate(w=nav_html.write)
-    w(nav_html.getvalue())
-    view.render(w=w)
-    w(nav_html.getvalue())
-    w(u'</div>\n')  # closes id=contentmain
-    self.content_footer(view)
-    w(u'</div>\n')  # closes div#pageContent
-    w(u'</div>\n')  # closes div.%(prefix)s-%(col)s
-
-
-@monkeypatch(ajaxcontroller.AjaxFunction)
-def _call_view(self, view, paginate=False, **kwargs):
-    divid = self._cw.form.get('divid')
-    # we need to call pagination before with the stream set
-    try:
-        stream = view.set_stream()
-    except AttributeError:
-        stream = UStringIO()
-        kwargs['w'] = stream.write
-        assert not paginate
-    if divid == 'contentmain':
-        # ensure divid isn't reused by the view (e.g. table view)
-        del self._cw.form['divid']
-        # mimick main template behaviour
-        paginate = True
-    if divid == 'contentmain':
-        stream.write(u'<div id="contentmain">')
-    nav_html = UStringIO()
-    if paginate and not view.handle_pagination:
-        view.paginate(w=nav_html.write)
-    stream.write(nav_html.getvalue())
-    view.render(**kwargs)
-    stream.write(nav_html.getvalue())
-    if divid == 'contentmain':
-        stream.write(u'</div>')
-    extresources = self._cw.html_headers.getvalue(skiphead=True)
-    if extresources:
-        stream.write(u'<div class="ajaxHtmlHead">\n')
-        stream.write(extresources)
-        stream.write(u'</div>\n')
-    return stream.getvalue()
-
-
 # Fixed rql reqwrite (https://www.cubicweb.org/ticket/17074119)
 
 from cubicweb.rqlrewrite import RQLRewriter, n, remove_solutions  # noqa
