@@ -36,7 +36,7 @@ class AssignArkWebService(json.JsonMixIn, View):
     # XXX could check Accept=application/json
     def call(self):
         org_ark = self._cw.form['organization']
-        org_ark = org_ark.replace('ark://', '')
+        org_ark = org_ark.replace('ark:/', '')
 
         def error(msg):
             self.wdata([{'error': msg.format(org_ark)}])
