@@ -140,7 +140,7 @@ class OAIRequestTC(CubicWebTC):
                 ('scregneugneu', 'invalid set specifier scregneugneu'),
             ]:
                 with self.subTest(setspec=setspec):
-                    oairq = OAIRequest('http://testing.fr', setspec=setspec)
+                    oairq = OAIRequest('https://localhost:80', setspec=setspec)
                     with self.assertRaises(OAIError) as cm:
                         oairq.rset_from_setspec(req)
                     self.assertEqual(cm.exception.errors, {'noRecordsMatch': msg})
@@ -227,7 +227,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
     def test_noverb(self):
         with self.admin_access.web_request() as req:
             result = self.oai_request(req)
-        self.assertIn('<request>http://testing.fr/cubicweb/oai</request>',
+        self.assertIn('<request>https://localhost:80/oai</request>',
                       result)
         self.assertIn('<error code="badVerb">no verb specified</error',
                       result)
@@ -235,7 +235,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
     def test_badverb(self):
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='coucou')
-        self.assertIn('<request>http://testing.fr/cubicweb/oai</request>',
+        self.assertIn('<request>https://localhost:80/oai</request>',
                       result)
         self.assertIn('<error code="badVerb">illegal verb "coucou"</error>',
                       result)
@@ -246,7 +246,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         pscheme, dscheme = self._setup_schemes()
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='ListSets')
-        self.assertIn('<request verb="ListSets">http://testing.fr/cubicweb/oai</request>',
+        self.assertIn('<request verb="ListSets">https://localhost:80/oai</request>',
                       result)
         for spec in ('agent', 'organizationunit', 'conceptscheme', 'profile',
                      'concept'):
