@@ -467,7 +467,7 @@ class AssignArkWebServiceTC(CubicWebTC):
             result = self.app_handle_request(req, 'ark')
             self.assertEqual(json.loads(result),
                              [{'ark': '0/a000000001'}])
-        params = {'organization': 'ark://' + org_ark}
+        params = {'organization': 'ark:/' + org_ark}
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'},
                 method='POST', **params) as req:
