@@ -102,6 +102,7 @@ class SAEMRefHooksTC(CubicWebTC):
             cnx.commit()
             self.assertMDNow(transfer)
             self.resetMD(cnx, transfer)
+            self.resetMD(cnx, scheme)
             # edit relation to a composite children
             code = scheme.reverse_in_scheme[0]
             rule_seq = cnx.create_entity('SEDASeqAccessRuleRule',
@@ -112,6 +113,8 @@ class SAEMRefHooksTC(CubicWebTC):
                                      seda_seq_access_rule_rule=rule_seq)
             cnx.commit()
             self.assertMDNow(transfer)
+            # should not have touched scheme's date
+            self.assertEqual(scheme.modification_date, YESTERDAY)
             self.resetMD(cnx, transfer)
             # edit link from composite children to an entity which is not part of the container
             rule_seq.cw_set(seda_rule=None)
@@ -126,13 +129,11 @@ class SAEMRefHooksTC(CubicWebTC):
             cnx.commit()
             self.resetMD(cnx, transfer)
             # edit link from root to an entity which is not part of the container
-            # XXX that shouldn't change anything for this special relation
-            agent = testutils.organization_unit(
+            organization_unit = testutils.organization_unit(
                 cnx, u'marcel', archival_roles=['deposit'])
-            transfer.cw_set(reverse_use_profile=agent)
+            transfer.cw_set(reverse_use_profile=organization_unit)
             cnx.commit()
-            self.assertMDNow(transfer)
-            self.resetMD(cnx, transfer)
+            self.assertEqual(transfer.modification_date, YESTERDAY)
 
     def test_externaluri_to_concept(self):
         with self.admin_access.repo_cnx() as cnx:
@@ -501,6 +502,44 @@ class EntityLifeCycleTC(CubicWebTC):
             concept.cw_delete()
             cnx.commit()
 
+    def test_inter_containers(self):
+        with self.admin_access.repo_cnx() as cnx:
+            scheme = testutils.scheme_for_type(
+                cnx, 'seda_rule', 'SEDASeqAccessRuleRule', u'AR038')
+            code = scheme.reverse_in_scheme[0]
+            transfer = testutils.setup_profile(cnx)
+            unit, unit_alt, unit_alt_seq = testutils.create_archive_unit(transfer)
+            cnx.commit()
+
+            nb_scheme_activities = len(cnx.find('Activity', used=scheme.eid))
+            nb_concept_activities = len(cnx.find('Activity', used=code.eid))
+            nb_transfer_activities = len(cnx.find('Activity', used=transfer.eid))
+
+            rule_seq = cnx.create_entity(
+                'SEDASeqAccessRuleRule',
+                reverse_seda_start_date=cnx.create_entity('SEDAStartDate'),
+                seda_rule=code)
+            cnx.create_entity(
+                'SEDAAccessRule',
+                seda_access_rule=transfer,
+                seda_seq_access_rule_rule=rule_seq)
+            cnx.commit()
+
+            self.assertEqual(len(cnx.find('Activity', used=code.eid)),
+                             nb_concept_activities)
+            self.assertEqual(len(cnx.find('Activity', used=transfer.eid)),
+                             nb_transfer_activities + 1)
+
+            cnx.create_entity('SEDAMimeTypeCodeListVersion',
+                              seda_mime_type_code_list_version_from=transfer,
+                              seda_mime_type_code_list_version_to=scheme)
+            cnx.commit()
+
+            self.assertEqual(len(cnx.find('Activity', used=scheme.eid)),
+                             nb_scheme_activities)
+            self.assertEqual(len(cnx.find('Activity', used=transfer.eid)),
+                             nb_transfer_activities + 2)
+
 
 class SEDAArchiveTransferHooksTC(CubicWebTC):
 
